#
# spec file for package spacewalksd
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# package renaming fun :(
%define rhn_client_tools spacewalk-client-tools
%define rhn_setup	 spacewalk-client-setup
%define rhn_check	 spacewalk-check
%define rhnsd		 spacewalksd
#
Name:           spacewalksd
Version:        5.0.37.1
Release:        1.18
Summary:        Spacewalk query daemon
License:        GPL-2.0
Group:          System Environment/Base
Source0:        spacewalksd-git-0.ef4ba4f.tar.gz
Source1:        %{name}-rpmlintrc
Url:            https://fedorahosted.org/spacewalk
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  gettext
Provides:       rhnsd = %{version}-%{release}
Obsoletes:      rhnsd < %{version}-%{release}

Requires:       %{rhn_check} >= 0.0.8
BuildRequires:  gcc
%if 0%{?suse_version}
Requires(post): aaa_base
Requires(preun): aaa_base
BuildRequires:  sysconfig
%if 0%{?suse_version} >=1210
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%else
Requires(preun): %fillup_prereq %insserv_prereq
%endif
%else
%if 0%{?fedora}
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(post): systemd-sysv
Requires(preun): systemd-sysv
Requires(post): systemd-units
Requires(preun): systemd-units
BuildRequires:  systemd-units
%else
Requires(post): chkconfig
Requires(preun): chkconfig
# This is for /sbin/service
Requires(preun): initscripts
Requires(postun): initscripts
%endif
%endif

%description
The Red Hat Update Agent that automatically queries the Red Hat
Network servers and determines which packages need to be updated on
your machine, and runs any actions.

%prep
%setup -q -n spacewalksd-git-0.ef4ba4f

%build
make -f Makefile.rhnsd %{?_smp_mflags} CFLAGS="-pie -fPIE -Wl,-z,relro,-z,now %{optflags}"

%install
make -f Makefile.rhnsd install VERSION=%{version}-%{release} PREFIX=$RPM_BUILD_ROOT MANPATH=%{_mandir} INIT_DIR=$RPM_BUILD_ROOT/%{_initrddir}

%if 0%{?suse_version} && 0%{?suse_version} < 1210
install -m 0755 rhnsd.init.SUSE $RPM_BUILD_ROOT/%{_initrddir}/rhnsd
# add rclink
ln -sf ../../etc/init.d/rhnsd $RPM_BUILD_ROOT/%{_sbindir}/rcrhnsd
%endif
%if 0%{?fedora} || 0%{?suse_version} >= 1210 || 0%{?rhel} >= 7
rm $RPM_BUILD_ROOT/%{_initrddir}/rhnsd
mkdir -p $RPM_BUILD_ROOT/%{_unitdir}
install -m 0644 rhnsd.service $RPM_BUILD_ROOT/%{_unitdir}/
install -m 0644 spacewalk-update-status.service $RPM_BUILD_ROOT/%{_unitdir}/
%endif
%if 0%{?suse_version}
# remove all unsupported translations
cd $RPM_BUILD_ROOT
for d in usr/share/locale/*; do
  if [ ! -d "/$d" ]; then
    rm -rfv "./$d"
  fi
done
cd -
%if 0%{?suse_version} >= 1210
rm -f $RPM_BUILD_ROOT/%{_sbindir}/rcrhnsd
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcrhnsd
%endif
%endif

%find_lang rhnsd

%{!?systemd_post: %global systemd_post() if [ $1 -eq 1 ] ; then /usr/bin/systemctl enable %%{?*} >/dev/null 2>&1 || : ; fi; }
%{!?systemd_preun: %global systemd_preun() if [ $1 -eq 0 ] ; then /usr/bin/systemctl --no-reload disable %%{?*} > /dev/null 2>&1 || : ; /usr/bin/systemctl stop %%{?*} > /dev/null 2>&1 || : ; fi; }
%{!?systemd_postun_with_restart: %global systemd_postun_with_restart() /usr/bin/systemctl daemon-reload >/dev/null 2>&1 || : ; if [ $1 -ge 1 ] ; then /usr/bin/systemctl try-restart %%{?*} >/dev/null 2>&1 || : ; fi; }

%if 0%{?suse_version} >= 1210
%pre
%service_add_pre rhnsd.service
%service_add_pre spacewalk-update-status.service
%endif

%post
%if 0%{?suse_version}
%if 0%{?suse_version} >= 1210
%service_add_post rhnsd.service
%service_add_post spacewalk-update-status.service
%else
%{fillup_and_insserv rhnsd}
%endif
%else
if [ -f /etc/init.d/rhnsd ]; then
    /sbin/chkconfig --add rhnsd
fi
if [ -f %{_unitdir}/rhnsd.service ]; then
    %systemd_post rhnsd.service
    %systemd_post spacewalk-update-status.service
    if [ "$1" = "2" ]; then
        # upgrade from old init.d
        if [ -L /etc/rc2.d/S97rhnsd ]; then
            /usr/bin/systemctl enable rhnsd.service >/dev/null 2>&1
        fi
        rm -f /etc/rc?.d/[SK]??rhnsd
    fi
fi
%endif
if [ -f %{_unitdir}/spacewalk-update-status.service ]; then
    # take care that this is always enabled if it exists
    /usr/bin/systemctl --quiet enable spacewalk-update-status.service 2>&1 ||:
fi

%preun
%if 0%{?suse_version}
%if 0%{?suse_version} >= 1210
%service_del_preun rhnsd.service
%service_del_preun spacewalk-update-status.service
%else
%stop_on_removal rhnsd
exit 0
%endif
%else
if [ $1 = 0 ] ; then
    %if 0%{?fedora} || 0%{?rhel} >= 7
        %systemd_preun rhnsd.service
        %systemd_preun spacewalk-update-status.service
    %else
    service rhnsd stop >/dev/null 2>&1
    %endif
    if [ -f /etc/init.d/rhnsd ]; then
        /sbin/chkconfig --del rhnsd
    fi
fi
%endif

%postun
%if 0%{?suse_version}
%if 0%{?suse_version} >= 1210
%service_del_postun rhnsd.service
%service_del_postun spacewalk-update-status.service
%else
%restart_on_update rhnsd
%{insserv_cleanup}
%endif
%else
if [ "$1" -ge "1" ]; then
    %if 0%{?fedora} || 0%{?rhel} >= 7
    %systemd_postun_with_restart rhnsd.service
    %systemd_postun_with_restart spacewalk-update-status.service
    %else
    service rhnsd condrestart >/dev/null 2>&1 || :
    %endif
fi
%endif

%files -f rhnsd.lang
%defattr(-,root,root)
%dir %{_sysconfdir}/sysconfig/rhn
%config(noreplace) %{_sysconfdir}/sysconfig/rhn/rhnsd
%{_sbindir}/rhnsd
%if 0%{?fedora} || 0%{?suse_version} >= 1210 || 0%{?rhel} >= 7
%{_unitdir}/rhnsd.service
%{_unitdir}/spacewalk-update-status.service
%else
%{_initrddir}/rhnsd
%endif
%if 0%{?suse_version}
%{_sbindir}/rcrhnsd
%endif
%{_mandir}/man8/rhnsd.8*
%doc LICENSE

%changelog
* Mon Mar 26 2018 jgonzalez@suse.com
- version 5.0.37.1-1
- Sync with upstream (bsc#1083294)
- Updating .po translations from Zanata
* Mon Mar  5 2018 jgonzalez@suse.com
- version 5.0.36.2-1
- remove empty clean section from spec (bsc#1083294)
* Fri Feb 23 2018 jgonzalez@suse.com
- version 5.0.36.1-1
- Cleanup specfiles
* Wed Jan 17 2018 jgonzalez@suse.com
- version 5.0.33.2-1
- Fix update mechanism when updating the updateservice (bsc#1073619)
* Thu Oct 26 2017 mc@suse.de
- version 5.0.33.1-1
- close and reopen syslog when redirecting child output
- no insserv on available in newer distributions
* Tue Aug  8 2017 fkobzik@suse.de
- version 5.0.26.3-1
- Fix permissions of PID files in spacewalksd (bsc#1049936)
* Tue May 23 2017 mc@suse.de
- version 5.0.26.2-1
- update changelog
* Mon Feb 13 2017 jrenner@suse.com
- version 5.0.19.2-1
- use spacewalk-update-status only on registered systems (bsc#1015136)
* Wed Mar  9 2016 mc@suse.de
- version 5.0.19.1-1
- delete file with input files after template is created
- update translations
* Mon Oct 12 2015 mc@suse.de
- version 5.0.17.2-1
- move name, version and release to the begin of the specfile
* Wed Oct  7 2015 mc@suse.de
- version 5.0.17.1-1
- systemd ready
* Mon Jun 22 2015 jrenner@suse.de
- version 5.0.14.8-1
- PIE+RELRO for rhnsd
* Tue Mar 31 2015 mc@suse.de
- version 5.0.14.7-1
- install new service and enable it (bsc#919433)
- add service spacewalk-update-status (bsc#919433)
* Tue Feb  3 2015 mc@suse.de
- version 5.0.14.6-1
- Getting rid of Tabs and trailing spaces
* Thu Dec 18 2014 mc@suse.de
- version 5.0.14.5-1
* Wed Sep  3 2014 ro@suse.de
- sanitize release line in specfile
* Thu Apr 10 2014 mc@suse.de
- version 5.0.14.4-1
* Thu Apr 10 2014 mc@suse.de
- fix release in specfile for SLE12 (bnc#872970)
* Fri Feb  7 2014 mc@suse.de
- version 5.0.14.3-1
- call find_lang after removal of unsupported translations
- remove unsupported translations and fix rc link
* Mon Jan 20 2014 mc@suse.de
- version 5.0.14.2-1
- use correct rc link
- support systemd for SLE12
- change license to SPDX format
* Tue Dec 10 2013 mc@suse.de
- version 5.0.14.1-1
- cleaning up old svn Ids
- rebranding few more strings in client stuff
- switch to 2.1
* Thu Nov 22 2012 jrenner@suse.de
- version 4.9.15.3-1
- do not start rhnsd in runlevel 2 which has no network
- call rhn-update-status only is exists and is executable
- call rhn-update-status at start to provide current uptime to server
* Mon May 14 2012 mc@suse.de
- version 4.9.15.2-1
- no use of /var/lock/subsys/ anymore
* Wed Mar 21 2012 mc@suse.de
- version 4.9.15.1-1
- Bumping package version
* Thu Dec 22 2011 mc@suse.de
- remove all unsupported translations
* Thu Nov  3 2011 ma@suse.de
- Adapt dependencies to renamed packages (bnc#722052)
* Wed Apr 27 2011 ma@suse.de
- Fix specfile to build on SLES10.
* Tue Mar 22 2011 mantel@suse.de
- debrand startup message (bnc#672637)
* Mon Feb  7 2011 mc@suse.de
- add rc link (bnc#669894)
* Fri Jan 21 2011 ma@suse.de
- Fix rpm scripts failing if system is not registered (bnc#652676)
* Wed Dec 15 2010 mc@suse.de
- fix specfile
- add Obsoletes: old name
* Wed Dec 15 2010 mc@suse.de
- rename to spacewalksd
* Thu Sep 16 2010 mantel@suse.de
- fix missing rhnsd.init.SUSE
* Wed Sep 15 2010 mantel@suse.de
- cleanup specfile: remove excessive *init.SUSE Source statement
* Wed Sep 15 2010 mantel@suse.de
- fix post-build-checks
* Tue Sep 14 2010 mantel@suse.de
- Initial release of rhnsd
